==> apache-cxf-3.6.9-src.zip: apache-cxf-3.6.9-src/systests/cdi/cdi-owb/cdi-producers-owb/src/test/java/org/apache/cxf/systest/jaxrs/cdi/ServerFactoryDebugExtension.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxrs.cdi;

import java.util.stream.Collectors;

import javax.inject.Singleton;

import org.apache.cxf.jaxrs.JAXRSServerFactoryBean;
import org.apache.cxf.jaxrs.ext.JAXRSServerFactoryCustomizationExtension;

@Singleton
public class ServerFactoryDebugExtension implements JAXRSServerFactoryCustomizationExtension {
    private String providers; 

    @Override
    public void customize(JAXRSServerFactoryBean bean) {
        providers = bean.getProviders()
            .stream()
            .map(t -> t.getClass().getSimpleName())
            .sorted()
            .collect(Collectors.joining(","));
    }

    String providers() {
        return providers;
    }
}

==> apache-cxf-4.1.5-src.zip: apache-cxf-4.1.5-src/systests/cdi/cdi-owb/cdi-producers-owb/src/test/java/org/apache/cxf/systest/jaxrs/cdi/ServerFactoryDebugExtension.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.jaxrs.cdi;

import java.util.stream.Collectors;

import jakarta.inject.Singleton;
import org.apache.cxf.jaxrs.JAXRSServerFactoryBean;
import org.apache.cxf.jaxrs.ext.JAXRSServerFactoryCustomizationExtension;

@Singleton
public class ServerFactoryDebugExtension implements JAXRSServerFactoryCustomizationExtension {
    private String providers; 

    @Override
    public void customize(JAXRSServerFactoryBean bean) {
        providers = bean.getProviders()
            .stream()
            .map(t -> t.getClass().getSimpleName())
            .sorted()
            .collect(Collectors.joining(","));
    }

    String providers() {
        return providers;
    }
}
